@@ -9,7 +9,7 @@ def get_public_ip():
 
 def get_sg(sg_name: str, profile: str):
     import boto3
-    sg_name = sg_name or 'jakub'
+    sg_name = sg_name or 'default'
     profile = profile or 'default'
 
     ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
@@ -18,7 +18,7 @@ def get_sg(sg_name: str, profile: str):
     return target_sg_str
 
 def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
-                    ports=[22, 8888], profile='default'):
+                    ports=[22, 8501, 8888], profile='default'):
     import boto3
 
     ip = f"{get_public_ip()}/32"
@@ -30,10 +30,12 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
     ec2_res = boto3.session.Session(profile_name=profile, region_name='eu-west-1').resource('ec2')
     sg_res = ec2_res.SecurityGroup(target_sg_str['GroupId'])
 
-    # TODO: make into a loop using ports
-    # Removes all previous permissions from this group (hence `jakub`)
+    # loop using ports to only remove SSH/Jupyter and not e.g. NFS
+    permissions_to_revoke = [ s for s in sg_res.ip_permissions if s['FromPort'] in ports ]
+
+    # Removes all relevant permissions from this group (originally as `jakub`)
     if sg_res.ip_permissions!=[]:
-        sg_res.revoke_ingress(IpPermissions=sg_res.ip_permissions)
+        sg_res.revoke_ingress(IpPermissions=permissions_to_revoke)
 
 
     description = 'Jakub Aux Jupyter'
