@@ -8,15 +8,17 @@ def monitor():
     return processes_per_gpu
 
 def submit(job_text):
-    tar_file = job_text.split(' ')[2]
+    tar_file = [ f for f in job_text.split(' ') if '.py' in f]
+    assert len(tar_file)==1
 
     while True:
         ppgpu = monitor()
         if sum(ppgpu)>1:
-            print(f'Still busy. File {tar_file} is in local: {tar_file in os.listdir()}.')
+            print(f'Still busy. File {tar_file[0]} is in local: {tar_file[0] in os.listdir()}.')
         else:
             print('Done, submitting a new job!')
-            sp.run(job_text, shell=True)
+            my_env = os.environ.copy()
+            sp.run(job_text, env=my_env)
             time.sleep(120)
         time.sleep(1)
 
